package EFS::CLI::Cabinet;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};

use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        location => { type => SCALAR },
        name     => { type => SCALAR },
    });

    my $location_rs = $class->get_resultset( q{Location} );

    my $location = $location_rs->retrieve_bynames_assert(
        name => $args{location},
    );

    my $resultset = $class->get_resultset;

    my ($cabinet) = $resultset->search({
        location => $location->id,
        name     => $args{name},
    });

    if ( $cabinet ) {

        STDOUT->print(
            q{Cabinet }, $cabinet->object_id, qq{ already exists.\n},
        );

    } else {

        $cabinet = $resultset->create({
            location => $location->id,
            name     => $args{name},
        });

        my $object_id  = $cabinet->object_id;
        my $cabinet_id = $cabinet->id;

        STDOUT->print(
            q{Defined cabinet }, $cabinet->object_id,
            q{, id = }, $cabinet->id, qq{\n},
        );

    }

    return $cabinet;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        location => { type => SCALAR },
        name     => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my $cabinet = $resultset->retrieve_bynames_assert(
        location => $args{location},
        name     => $args{name},
    );

    my $object_id = $cabinet->object_id;

    $cabinet->attrs->delete_all;
    $cabinet->delete;

    STDOUT->print( qq{Undefined cabinet $object_id\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        location => { type     => SCALAR,
                      optional => 1 },
        name     => { type     => SCALAR,
                      depends  => [qw(location)],
                      optional => 1 },
    });

    my $resultset = $class->get_resultset;

    my @cabinets = ();

    if ( not $args{location} ) {

        @cabinets = $resultset->all;

    } elsif ( not $args{name} ) {

        my $location_rs = $class->get_resultset( q{Location} );

        my $location = $location_rs->retrieve_bynames_assert(
            name => $args{location},
        );

        @cabinets = $location->cabinets;

    } else {

        $cabinets[0] = $resultset->retrieve_bynames_assert(
            location => $args{location},
            name     => $args{name},
        );

    }

    if ( not @cabinets ) {
        STDOUT->print( qq{No cabinets match the specified criteria\n} );
        return 1;
    }

    $class->display_objects(
        objects => [ $class->sort_objects( @cabinets ) ],
    );

    if ( scalar @cabinets != 1 ) {
        return 1;
    }

    my $cabinet = $cabinets[0];

    if ( my @attrs = $cabinet->attrs ) {
        $attrs[0]->display_objects( objects => \@attrs );
    }

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        location => { type => SCALAR },
        name     => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{cabinet} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
