package EFS::CLI::EFSServerCell;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        efsserver => { type => SCALAR },
        cell      => { type => SCALAR },
    });

    my $efsserver_rs = $class->get_resultset( q{EFSServer} );

    my $efsserver = $efsserver_rs->retrieve_bynames_assert(
        name => $args{efsserver},
    );

    my $cell_rs = $class->get_resultset( q{Cell} );

    my $cell = $cell_rs->retrieve_bynames_assert(
        name => $args{cell},
    );

    my $resultset = $class->get_resultset;

    my ($efsservercell) = $resultset->search({
        efsserver => $efsserver->id,
        cell      => $cell->id,
    });

    if ( $efsservercell ) {
        STDOUT->print( qq{EFSServer '$efsserver' already supports cell '$cell'\n} );
    } else {
        $efsservercell = $resultset->create({
            efsserver => $efsserver->id,
            cell      => $cell->id,
        });
        STDOUT->print( qq{EFSServer '$efsserver' now supports cell '$cell'\n} );
    }

    return $efsservercell;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        efsserver => { type => SCALAR },
        cell      => { type => SCALAR },
    });

    my $efsserver_rs = $class->get_resultset( q{EFSServer} );

    my $efsserver = $efsserver_rs->retrieve_bynames_assert(
        name => $args{efsserver},
    );

    my $cell_rs = $class->get_resultset( q{Cell} );

    my $cell = $cell_rs->retrieve_bynames_assert(
        name => $args{cell},
    );

    my $resultset = $class->get_resultset;

    my ($efsservercell) = $resultset->search({
        efsserver => $efsserver->id,
        cell      => $cell->id,
    });

    if ( $efsservercell ) {
        $efsservercell->delete;
        STDOUT->print( qq{EFSServer '$efsserver' no longer supports cell '$cell'\n} );
    } else {
        STDOUT->print( qq{EFSServer '$efsserver' does not support cell '$cell'\n} );
    }

    return 1;

}

sub display {
    die(
        qq{efs display efsservercell has been deprecated\n},
        qq{Use display efsserver or display cell instead\n},
    );
    return;
}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
