package EFS::CLI::Feature;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name  => { type => SCALAR },
        value => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($feature) = $resultset->search({ name => $args{name} });

    if ( $feature ) {

        STDOUT->print( qq{Feature '$feature' is already defined\n} );

        if ( $feature->value ne $args{value} ) {
            $feature->set_column( value => $args{value} );
            $feature->update;
            STDOUT->print( qq{Updated value of feature '$args{name}'\n} );
        }

    } else {

        $feature = $resultset->create({
            name  => $args{name},
            value => $args{value},
        });

        STDOUT->print( qq{Defined feature '$args{name}'\n} );

    }

    return $feature;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($feature) = $resultset->retrieve_bynames_assert(
        name => $args{name},
    );

    $feature->delete;

    STDOUT->print( qq{Undefined feature '$args{name}'\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( not $args{name} ) {
        $class->display_objects( objects => [ $resultset->all ] );
        return 1;
    }

    my ($feature) = $resultset->retrieve_bynames_assert(
        name => $args{name},
    );

    $class->display_objects( objects => [ $feature ] );

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{feature} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
