package EFS::CLI::Hostclass;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name        => { type => SCALAR },
        description => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($hostclass) = $resultset->search({ name => $args{name} });

    if ( $hostclass ) {

        STDOUT->print( qq{Hostclass '$hostclass' is already defined\n} );

        if ( $hostclass->description ne $args{description} ) {
            $hostclass->set_column( description => $args{description} );
            $hostclass->update;
            STDOUT->print( qq{Updated description of hostclass $hostclass\n} );
        }

    } else {

        $hostclass = $resultset->create({
            name        => $args{name},
            description => $args{description},
        });

        STDOUT->print( qq{Defined hostclass '$args{name}'\n} );

    }

    return $hostclass;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my $hostclass = $resultset->retrieve_bynames_assert(
        name => $args{name},
    );

    $hostclass->attrs->delete_all;
    $hostclass->delete;

    STDOUT->print( qq{Undefined hostclass '$args{name}'\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( not $args{name} ) {
        $class->display_objects( objects => [ $resultset->all ] );
        return 1;
    }

    my $hostclass = $resultset->retrieve_bynames_assert( name => $args{name} );

    $class->display_objects( objects => [ $hostclass ] );

    if ( my @attrs = $hostclass->attrs ) {
        $attrs[0]->display_objects( objects => \@attrs );
    }

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{hostclass} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
