package EFS::Groupname;

use strict;
use warnings;
use English;

use Moose;
use Params::Validate qw( :all );

has q{name} => (
    is       => q{ro},
    isa      => q{Str},
    required => 1,
);
with q{EFS::Stringification};

has q{members} => (
    is         => q{ro},
    isa        => q{ArrayRef[Str]},
    lazy_build => 1,
    init_arg   => undef,
    auto_deref => 1,
);

sub _build_members {

    my $self = shift;

    my $groupid = $self->groupid;

    my @members = split m/\s+/msx, $self->_grnam->[3];

    setpwent || die qq{Unable to setpwent: $ERRNO\n};

    while ( my @getpwent = getpwent ) {
        if ( $getpwent[3] == $groupid ) {
            push @members, $getpwent[0];
        }
    }

    endpwent; # No return value, supposedly...

    return \@members;
}

has q{_grnam} => (
    is         => q{ro},
    isa        => q{ArrayRef[Str]},
    lazy_build => 1,
    init_arg   => undef,
);

sub _build__grnam {

    my $self = shift;
    my $name = $self->name;

    #
    # This is a workaround for the fact that gid=0 is not standardized across
    # all UNIX implementations.  We really just want whatever gid=0 is when we
    # specify 'root'
    #
    if ( $name eq q{root} ) {
        my @getgrgid = getgrgid( 0 ) or
            die qq{No such group ID '0'\n};
        return \@getgrgid;
    }
    else {
        my @getgrnam = getgrnam( $name ) or
            die qq{No such groupname '$name'\n};
        return \@getgrnam;
    }

}

{

    sub BUILD {
        return shift->groupid;
    }


    sub as_string {
        return shift->name;
    }

    sub groupid {
        return shift->_grnam->[2];
    }

}

no Moose;
__PACKAGE__->meta->make_immutable;
1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
