#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 7;

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new;
my $config = $test->get_config;

my $secondary_user  = $config->get_value( q{Global}, q{secondary_user} );
my $secondary_group = $config->get_value( q{Global}, q{secondary_group} );

$test->efs_test_command(
    run_as  => q{efsops},
    name    => q{(setup) efs display metaproj testmeta},
    command => q{efs display metaproj testmeta},
    bail    => 1,
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs display parameter maintenance_mode},
    not     => 1,
    bail    => 1,
    expect  => q{No such parameter 'maintenance_mode'},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs define parameter maintenance_mode 'testing 123'},
);

# This verifies that non-efsops people get told where to go

$test->efs_test_command(
    command => qq{efs define grouprights testmeta prod $secondary_group},
    not     => 1,
    expect  => [
        q{EFS is currently in maintenance mode.},
        q{Only efsops can run authorized commands.},
        q{testing 123},
        qr{Exit\s+status\s+from\s+efs\s+server\s+not\s+received}msx,
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs undef parameter maintenance_mode},
);

$test->efs_test_command(
    command => qq{efs define grouprights testmeta prod $secondary_group},
);

$test->efs_test_command(
    command => qq{efs undef grouprights testmeta prod $secondary_group},
);

exit 0;
