#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $region   = q{testregion};
my $campus   = q{testcampus};
my $location = q{testlocation};

my $supmac = reverse $campus;

$test->efs_test_command(
    command => qq{efs define region $region 'test region'}
);

$test->efs_test_command(
    command => qq{efs define campus $region $campus 'test campus'}
);

$test->efs_test_command(
    name    => q{Verifying that the location doesn't exist...},
    command => qq{efs display location $region $campus $location},
    not     => 1,
    bail    => 1,
    expect  => [ qq{No such location $region/$campus/$location}, ],
);

$test->efs_test_command(
    name    => q{Define a bogus location},
    command => qq{efs define location $region $campus UPPERCASE test},
    not     => 1,
    expect  => [
        q{Invalid location 'UPPERCASE'},
        q{Must consist solely of lower case letters and numbers (a-z0-9)},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
);

$test->efs_test_command(
    name    => qq{Define the location $location},
    command => qq{efs define location $region $campus $location temp},
    expect  => [ qq{Defined location $region/$campus/$location}, ],
);

$test->efs_test_command(
    name    => qq{Define the location $campus again},
    command => qq{efs define location $region $campus $location 'test location'},
    expect  => [
        qq{Location $region/$campus/$location is already defined},
        qq{Updated description of location $region/$campus/$location},
    ],
);

$test->efs_test_command(
    name    => q{Define the other campus},
    command => qq{efs define campus $region $supmac 'other campus'},
);

$test->efs_test_command(
    name    => q{Try to define the location in the other campus},
    command => qq{efs define location $region $supmac $location 'other location'},
    not     => 1,
    expect  => [
        qq{Location $location is already defined, }
            . qq{but in campus $campus, region $region},
    ],
);

$test->efs_test_command(
    name    => q{Set an attribute for the location},
    command => qq{efs setattr location $region $campus $location foo bar},
    expect  => [
        qq{For location '$region/$campus/$location', defined attribute as:},
        q{'foo' => 'bar'},
    ],

);

$test->efs_test_command(
    command => qq{efs display campus $region $campus},
    expect  => [
        qr{Campus \s+ Description}msx,
        qr{=+}msx,
        qr{$campus \s+ test \s+ campus}msx,
        qr{Region \s+ Campus \s+ Location}msx,
        qr{=+}msx,
        qr{$region \s+ $campus \s+ $location}msx,
    ],
);

$test->efs_test_command(
    command => qq{efs display location $region $campus $location},
    expect  => [
        qr{Region \s+ Campus \s+ Location \s+ Description}msx,
        qr{=+}msx,
        qr{$region \s+ $campus \s+ $location \s+ test \s+ location}msx,
        qr{Region \s+ Campus \s+ Location \s+ Attribute \s+ Value}msx,
        qr{=+}msx,
        qr{$region \s+ $campus \s+ $location \s+ foo \s+ bar}msx,
    ],
);

$test->efs_test_command(
    name    => q{Try to undef the campus prematurely},
    command => qq{efs undef campus $region $campus},
    not     => 1,
    expect  => [
        qq{Unable to undef campus $region/$campus, because it has},
        q{the following locations:},
        qq{$location},
    ],
);

$test->efs_test_command(
    command => qq{efs undef location $region $campus $location},
);

$test->efs_test_command(
    command => qq{efs undef campus $region $campus},
);

$test->efs_test_command(
    command => qq{efs undef campus $region $supmac},
);

$test->efs_test_command(
    command => qq{efs undef region $region},
);

$test->efs_test_command(
    command => qq{efs history location $region $campus $location -count 4},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ location \s+ $region \s+ $campus \s+ $location}msx,
        qr{define \s+ location \s+ $region \s+ $campus \s+ $location}msx,
        qr{setattr \s+ location \s+ $region \s+ $campus \s+ $location \s+ foo \s+ bar}msx,
        qr{undef \s+ location \s+ $region \s+ $campus \s+ $location}msx,
    ],
);


