#!/usr/bin/env perl

use warnings;
use strict;
use English;

=head1 DESCRIPTION

Makes sure that we are not C<use>ing EFSPerl::Version anywhere.

=cut

use Test::More;
use File::Find;
use IO::File;

if ( ! -e q{inc/.author} ) {
    plan skip_all => q{no inc/.author, and it is on purpose ;)}
}

plan q{no_plan};

my %used;
find( \&wanted, qw/ lib bin xt t test util / );

sub wanted {
    return unless -f $_;
    return if $File::Find::dir =~ m{/.svn($|/)}msx;
    return if $File::Find::name =~ /~$/msx;
    return if $File::Find::name =~ /\.(pod|html)$/msx;
    return if $File::Find::name =~ /efs_(upload_new|download_old)_database/msx;

    ##  read in the file from disk
    my $filename = $_;
    local $RS = undef;
    my $fh = IO::File->new($filename) || do {
        warn qq{Unable to open $filename: $ERRNO\n};
        ok( 0, qq{Opened $filename} );
        return;
    };
    my $data = <$fh>;
    $fh->close;

    ##  strip pod, in a really idiotic way. Good enough though
    $data =~ s/^=head.+?(^=cut|\Z)//gmsx;

    ##  look for 'use EFSPerl::Version' statements
    while ( $data =~ /^\s*use\s+EFSPerl::Version\b/gmsx ) {
        $used{$File::Find::name}++;
    }

    return;
}

##  fail on all modules found
if ( %used ) {
    foreach ( sort keys %used ) {
        fail(qq{$_ mentioned in $used{$_}});
    }
}
else {
    pass(q{no EFSPerl::Version usage found});
}

